Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(71)

Unified Diff: chrome/browser/autofill/android/personal_data_manager_android.h

Issue 2515853002: [Payments] Fix new billing address label. (Closed)
Patch Set: Updated test and code added in the Rebase Created 4 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/autofill/android/personal_data_manager_android.h
diff --git a/chrome/browser/autofill/android/personal_data_manager_android.h b/chrome/browser/autofill/android/personal_data_manager_android.h
index 0e8ded207ee2c9707017c551beafafc5a9505776..9a78511085bc7b64c87d95ca9b3aa3892647bf5e 100644
--- a/chrome/browser/autofill/android/personal_data_manager_android.h
+++ b/chrome/browser/autofill/android/personal_data_manager_android.h
@@ -96,10 +96,20 @@ class PersonalDataManagerAndroid
jboolean include_organization_in_label,
jboolean include_country_in_label);
- // Returns the label of the given profile for PaymentRequest. This label does
- // not contain the full name or the email address. All other fields are
- // included in the label.
- base::android::ScopedJavaLocalRef<jstring> GetAddressLabelForPaymentRequest(
+ // Returns the shipping label of the given profile for PaymentRequest. This
+ // label does not contain the full name or the email address. All other fields
+ // are included in the label.
+ base::android::ScopedJavaLocalRef<jstring>
+ GetShippingAddressLabelForPaymentRequest(
+ JNIEnv* env,
+ const base::android::JavaParamRef<jobject>& unused_obj,
+ const base::android::JavaParamRef<jobject>& jprofile);
+
+ // Returns the billing label of the given profile for PaymentRequest. This
+ // label does not contain the company name, the phone number, the country or
+ // the email address. All other fields are included in the label.
+ base::android::ScopedJavaLocalRef<jstring>
+ GetBillingAddressLabelForPaymentRequest(
JNIEnv* env,
const base::android::JavaParamRef<jobject>& unused_obj,
const base::android::JavaParamRef<jobject>& jprofile);

Powered by Google App Engine
This is Rietveld 408576698